package com.jjt.elec.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.jjt.elec.domain.ElecPrice;

/**
 * 电费价格配置Mapper接口
 * 
 * @author wukai
 * @date 2025-03-14
 */
public interface ElecPriceMapper extends BaseMapper<ElecPrice>
{
    /**
     * 查询电费价格配置
     * 
     * @param priceId 电费价格配置主键
     * @return 电费价格配置
     */
    public ElecPrice selectElecPriceByPriceId(Long priceId);

    /**
     * 查询电费价格配置列表
     * 
     * @param elecPrice 电费价格配置
     * @return 电费价格配置集合
     */
    public List<ElecPrice> selectElecPriceList(ElecPrice elecPrice);

    /**
     * 新增电费价格配置
     * 
     * @param elecPrice 电费价格配置
     * @return 结果
     */
    public int insertElecPrice(ElecPrice elecPrice);

    /**
     * 修改电费价格配置
     * 
     * @param elecPrice 电费价格配置
     * @return 结果
     */
    public int updateElecPrice(ElecPrice elecPrice);

    /**
     * 删除电费价格配置
     * 
     * @param priceId 电费价格配置主键
     * @return 结果
     */
    public int deleteElecPriceByPriceId(Long priceId);

    /**
     * 批量删除电费价格配置
     * 
     * @param priceIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteElecPriceByPriceIds(Long[] priceIds);
}
